@@ -3,8 +3,8 @@
 
 __author__ = "Timo Stollenwerk (timo@zmag.de)"
 __license__ = "GNU General Public License (GPL)"
-__revision__ = "$Rev: 225 $"
-__date__ = "$Date: 2008-03-07 09:23:44 +0100 (Fri, 07 Mar 2008) $"
+__revision__ = "$Rev: 233 $"
+__date__ = "$Date: 2008-03-07 15:19:05 +0100 (Fri, 07 Mar 2008) $"
 __URL__ = "$URL: http://svn.zmag.de/svn/python/docbook2sla/trunk/docbook2sla/docbook2sla.py $"
 
 import os, sys
@@ -51,33 +51,33 @@ class DocBook2Sla(object):
         """ Creates a Scribus file from a DocBook source. """
 
         if _debug:
-            print"---- create ----"
+            LOG.info("create(%s, %s, output_filename=%s, validate=%s" % (docbookfn, scribusfn, output_filename, validate))
 
         # validate input files
         if validate:
-            print 'validate docbook: %s' % self.validate(docbookfn)
-            print 'validate scribus: %s' % self.validate(scribusfn)
+            LOG.info('validate docbook: %s' % self.validate(docbookfn))
+            LOG.info('validate scribus: %s' % self.validate(scribusfn))
 
 
         # generate id : content.xml -> content.id.xml
         docbook_with_ids = self.transform(docbookfn, self.xsl_generateid)
 
         if _debug:
-            print "DEBUG: docbook_with_ids written to '%s'" % docbook_with_ids
+            LOG.info("DEBUG: docbook_with_ids written to '%s'" % docbook_with_ids)
             #return open(docbook_with_ids, 'r').read()
 
         # docbook2pageobject : 01_content.id.xml -> pageobjects.xml
         scribus_pageobjects = self.transform(docbook_with_ids, self.xsl_docbook2pageobject)
 
         if _debug:
-            print "DEBUG: scribus_pageobjects written to '%s'" % scribus_pageobjects
+            LOG.info("DEBUG: scribus_pageobjects written to '%s'" % scribus_pageobjects)
             #return open(scribus_pageobjects, 'r').read()
 
         # wrapper : pageobjects.xml + clean134.sla -> output.sla
         output = self.transform(scribusfn, self.xsl_wrapper, secondinputfn=scribus_pageobjects)
 
         if _debug:
-            print "DEBUG: output written to '%s'" % output
+            LOG.info("DEBUG: output written to '%s'" % output)
             #return open(output, 'r').read()
 
         # write to output filename if specified
@@ -90,14 +90,13 @@ class DocBook2Sla(object):
     def syncronize(self, docbookfn, scribusfn, output_filename=None, validate=False):
         """ Syncronize changes in a docbook file into a scribus file. """
 
-        if _debug:
-            print"---- syncronize ----"
+        LOG.info("syncronize(%s, %s, output_filename=%s, validate=%s" % (docbookfn, scribusfn, output_filename, validate))
 
         # validate input files
         if validate:
             try:
-                print 'validate docbook: %s' % self.validate(docbookfn)
-                print 'validate scribus: %s' % self.validate(scribusfn)
+                LOG.info('validate docbook: %s' % self.validate(docbookfn))
+                LOG.info('validate scribus: %s' % self.validate(scribusfn))
             except:
                 print >>sys.stderr, 'Error validating %s and %s' % (docbookfn, scribusfn)
                 raise
@@ -106,21 +105,21 @@ class DocBook2Sla(object):
         docbook_with_ids = self.transform(docbookfn, self.xsl_generateid)
 
         if _debug:
-            print "DEBUG: docbook_with_ids written to '%s'" % docbook_with_ids
+            LOG.info("DEBUG: docbook_with_ids written to '%s'" % docbook_with_ids)
             #return open(docbook_with_ids, 'r').read()
 
         # docbook2pageobject : 01_content.id.xml -> pageobjects.xml
         scribus_pageobjects = self.transform(docbook_with_ids, self.xsl_docbook2pageobject)
 
         if _debug:
-            print "DEBUG: scribus_pageobjects written to '%s'" % scribus_pageobjects
+            LOG.info("DEBUG: scribus_pageobjects written to '%s'" % scribus_pageobjects)
             #return open(scribus_pageobjects, 'r').read()
 
         # wrapper : pageobjects.xml + clean134.sla -> output.sla
         output = self.transform(scribusfn, xsl_wrapper, secondinputfn=scribus_pageobjects)
 
         if _debug:
-            print "DEBUG: output written to '%s'" % output
+            LOG.info("DEBUG: output written to '%s'" % output)
             #return open(output, 'r').read()
 
         # write to output filename if specified
