@@ -14,7 +14,8 @@ dirname = os.path.dirname(__file__)
 class TransformationTestCase(unittest.TestCase):
 
     def setUp(self):
-        pass
+
+        self.d2s = DocBook2Sla()
 
 
     def testTransformation(self):
@@ -23,13 +24,9 @@ class TransformationTestCase(unittest.TestCase):
         transformfn = os.path.join(os.path.dirname(__file__), 'data', 'testTransformation.xsl')
         expectedfn = os.path.join(os.path.dirname(__file__), 'data', 'testTransformation.expected.xml')
 
-        print >>sys.stderr, 'testSimpleTransformation: %s, %s' % (inputfn, transformfn)
-
-        d2s = DocBook2Sla()
-
         # try to transform inputfn
         try:
-            outputfn = d2s.transform(inputfn, transformfn)
+            outputfn = self.d2s.transform(inputfn, transformfn)
         except:
             print >>sys.stderr, 'Error transforming %s with %s' % (inputfn, transformfn)
             raise
@@ -58,13 +55,9 @@ class TransformationTestCase(unittest.TestCase):
         transformfn = os.path.join(os.path.dirname(__file__), 'data', 'testTransformationWithParam.xsl')
         expectedfn = os.path.join(os.path.dirname(__file__), 'data', 'testTransformationWithParam.expected.xml')
 
-        print >>sys.stderr, 'testTransformationWithParam: %s, %s' % (inputfn, transformfn)
-
-        d2s = DocBook2Sla()
-
         # try to transform inputfn
         try:
-            outputfn = d2s.transform(inputfn, transformfn, secondinputfn=secondinputfn)
+            outputfn = self.d2s.transform(inputfn, transformfn, secondinputfn=secondinputfn)
 
         except:
             print >>sys.stderr, 'Error transforming %s with %s' % (inputfn, transformfn)
@@ -81,6 +74,28 @@ class TransformationTestCase(unittest.TestCase):
         return outputfn
 
 
+class StylesheetsTestCase(unittest.TestCase):
+
+    def setUp(self):
+
+        self.d2s = DocBook2Sla()
+
+    def testGenerateId(self):
+        """ test the generateId function """
+        xsl_generateid = os.path.abspath(os.path.join(dirname,
+                                                      '..',
+                                                      'xsl',
+                                                      'generate-id.xsl'))
+
+        outputfn = self.d2s.transform('tests/data/xml/article.xml',
+                                      xsl_generateid)
+
+        output = open(outputfn, 'r').read()
+        outputtree = etree.XML(output)
+
+        article_id = outputtree.xpath("count(//*[@id])")
+        self.assertEqual(article_id, 3.0)
+
     def testDocBook2PageobjectsArticle(self):
         """ Test transformation from DocBook article to Scribus pageobjects. """
 
@@ -91,13 +106,14 @@ class TransformationTestCase(unittest.TestCase):
         if not os.path.exists(xsl_docbook2pageobject):
             raise IOError('%s does not exist' % xsl_docbook2pageobject)
 
-        d2s = DocBook2Sla()
-        outputfn = d2s.transform('tests/data/xml/article.xml',
+        outputfn = self.d2s.transform('tests/data/xml/article.xml',
                                  xsl_docbook2pageobject)
         output = open(outputfn, 'r').read()
         outputtree = etree.XML(output)
+
+        # 4 pageobjects expected (1 complex, 3 simple)
         count_pageobjects = outputtree.xpath("count(//PAGEOBJECT)")
-        self.assertEqual(count_pageobjects, 4)
+        self.assertEqual(count_pageobjects, 4.0)
 
 
     def testDocBook2PageobjectsBook(self):
@@ -110,25 +126,24 @@ class TransformationTestCase(unittest.TestCase):
         if not os.path.exists(xsl_docbook2pageobject):
             raise IOError('%s does not exist' % xsl_docbook2pageobject)
 
-        d2s = DocBook2Sla()
-        outputfn = d2s.transform('tests/data/xml/book.xml',
+        outputfn = self.d2s.transform('tests/data/xml/book.xml',
                                  xsl_docbook2pageobject)
         output = open(outputfn, 'r').read()
         outputtree = etree.XML(output)
+
+        # 10 pageobjects expected (2 complex, 8 simple)
         count_pageobjects = outputtree.xpath("count(//PAGEOBJECT)")
-        self.assertEqual(count_pageobjects, 4.0)
+        self.assertEqual(count_pageobjects, 10.0, output)
 
 
     def testWrapper(self):
         """ Test the wrapper function. """
 
-        d2s = DocBook2Sla()
-
         inputfn = os.path.join(os.path.dirname(__file__), 'data', 'testWrapper.input.xml')
         secondinputfn = os.path.join(os.path.dirname(__file__), 'data', 'testWrapper.secondinput.xml')
         transformfn = os.path.abspath(os.path.join(dirname, '..', 'xsl', 'wrapper.xsl'))
 
-        outputfn = d2s.transform(inputfn, transformfn, secondinputfn=secondinputfn)
+        outputfn = self.d2s.transform(inputfn, transformfn, secondinputfn=secondinputfn)
         output = open(outputfn, 'r').read()
         outputtree = etree.XML(output)
 
@@ -138,24 +153,28 @@ class TransformationTestCase(unittest.TestCase):
 
         # make sure the number of pageobjects is correct
         count_pageobjects = outputtree.xpath("count(//PAGEOBJECT)")
-        self.assertEqual(count_pageobjects, 2.0)
+        self.assertEqual(count_pageobjects, 2.0, output)
 
         # make sure there is a pageobject with id1
         po1 = outputtree.xpath("name(//PAGEOBJECT[@ANNAME='id1'])")
-        self.assertEqual(po1, "PAGEOBJECT")
+        self.assertEqual(po1, "PAGEOBJECT", output)
 
         # make sure there is a pageobject with id2
         po1 = outputtree.xpath("name(//PAGEOBJECT[@ANNAME='id2'])")
-        self.assertEqual(po1, "PAGEOBJECT")
+        self.assertEqual(po1, "PAGEOBJECT", output)
 
 
+class CreateScribusDocumentTestCase(unittest.TestCase):
+
+    def setUp(self):
+
+        self.d2s = DocBook2Sla()
 
     def testCreateArticle(self):
         """ Test create() function with a DocBook article """
 
-        d2s = DocBook2Sla()
-        outputfn = d2s.create('tests/data/xml/article.xml',
-                              'tests/data/scribus/clean134.sla')
+        outputfn = self.d2s.create('tests/data/xml/article.xml',
+                                   'tests/data/scribus/clean134.sla')
         output = open(outputfn, 'r').read()
         outputtree = etree.XML(output)
 
@@ -169,23 +188,33 @@ class TransformationTestCase(unittest.TestCase):
 
     def testCreateBook(self):
         """ Test create() function with a DocBook book """
-        d2s = DocBook2Sla()
-        outputfn = d2s.create('tests/data/xml/book.xml',
+
+        outputfn = self.d2s.create('tests/data/xml/book.xml',
                               'tests/data/scribus/clean134.sla')
         output = open(outputfn, 'r').read()
         outputtree = etree.XML(output)
         count_pageobjects = outputtree.xpath("count(//PAGEOBJECT)")
-        self.assertEqual(count_pageobjects, 4.0)
+        self.assertEqual(count_pageobjects, 10.0)
 
-#    def testSyncronize(self):
-#        d2s = DocBook2Sla()
-#        print d2s.syncronize('tests/data/xml/article-1.xml',
+class SyncronizeScribusDocumentTestCase(unittest.TestCase):
+
+    def setUp(self):
+
+        self.d2s = DocBook2Sla()
+
+    def testSyncronize(self):
+        pass
+#
+#        print self.d2s.syncronize('tests/data/xml/article-1.xml',
 #                             'tests/data/output/create_output.sla',
 #                             'tests/data/output/syncronize_output.sla')
 
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(makeSuite(TransformationTestCase))
+    suite.addTest(makeSuite(StylesheetsTestCase))
+    suite.addTest(makeSuite(CreateScribusDocumentTestCase))
+    #suite.addTest(makeSuite(SyncronizeScribusDocumentTestCase))
     return suite
 
 if __name__ == "__main__":
